@@ -1,7 +1,6 @@
 from datetime import datetime
 from json import dumps
-from typing import List
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import BaseModel, validator, NonNegativeFloat
 
@@ -100,3 +99,63 @@ class Account(BaseModel):
     remainderDate: datetime
     externalId: Optional[str]
     accountGroupId: Optional[int]
+
+
+class AccountLink(BaseModel):
+    accountId: int
+    companyId: int
+    externalId: Optional[str]
+    title: Optional[str]
+
+
+class CompanyLinkModel(BaseModel):
+    companyId: int
+    externalId: Optional[str]
+    title: Optional[str]
+
+
+class CurrencyLinkModel(BaseModel):
+    currencyCode: str
+    title: Optional[str]
+
+
+class OperationCategoryLinkModel(BaseModel):
+    operationCategoryId: int
+    title: Optional[str]
+    externalId: Optional[str]
+
+
+class ProjectLinkModel(BaseModel):
+    projectId: int
+    title: Optional[str]
+    externalId: Optional[str]
+
+
+class ContrAgentLinkModel(BaseModel):
+    contrAgentId: int
+    title: Optional[str]
+    externalId: Optional[str]
+
+
+class OperationPartModel(BaseModel):
+    isCalculationCommitted: bool
+    project: Optional[ProjectLinkModel]
+    contrAgent: Optional[ContrAgentLinkModel]
+    operationCategory: Optional[OperationCategoryLinkModel]
+    value: float
+    valueInUserCurrency: float
+
+
+class OperationModel(BaseModel):
+    account: AccountLink
+    accountCompany: CompanyLinkModel
+    accountCurrency: CurrencyLinkModel
+    boundMoveOperationId: Optional[int]
+    comment: Optional[str]
+    isCommitted: Optional[bool]
+    operationCategory: OperationCategoryLinkModel
+    operationId: int
+    operationParts: List[OperationPartModel]
+    operationType: str
+    value: float
+    valueInUserCurrency: float
