@@ -97,25 +97,25 @@ def get_projects(changes_from_date=None):
     return items
 
 
-def create_income(operation: IncomeOutcomeOperation):
+def create_income(operation: IncomeOutcomeOperation) -> OperationModel:
     path = f'/api/v1/operations/income'
     json = operation.json()
     res, _ = pf_interaction.request('post', path, json=json)
-    return res.json()['data']
+    return OperationModel.parse_obj(res.json()['data'])
 
 
-def create_outcome(operation: IncomeOutcomeOperation):
+def create_outcome(operation: IncomeOutcomeOperation) -> OperationModel:
     path = f'/api/v1/operations/outcome'
     json = operation.json()
     res, _ = pf_interaction.request('post', path, json=json)
-    return res.json()['data']
+    return OperationModel.parse_obj(res.json()['data'])
 
 
-def create_move_operation(operation: MoveOperation):
+def create_move_operation(operation: MoveOperation) -> List[OperationModel]:
     path = f'/api/v1/operations/move'
     json = operation.json()
     res, _ = pf_interaction.request('post', path, json=json)
-    return res.json()['data']
+    return [OperationModel.parse_obj(d) for d in res.json()['data']]
 
 
 def create_account(account: Account):
